config

package
v0.0.0-...-84e6723 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2023 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	*viper.Viper
}

Config contains a reference to the viper configuration management.

func Get

func Get() *Config

Get returns the current instance of the config.

func New

func New() (*Config, error)

New tries to resolve and parse the YAML config file either in the current working dir or via command line argument.

Jump to